#!/bin/sh

set -e

cd debian/tests
g++ test.cpp $(pkg-config --cflags --libs systemc)
./a.out
rm -f a.out

